@@ -80,7 +80,7 @@ def setUserId(environ, res, cookieValue):
         if not conf.user_header_ticket:
             cookie = environ.get(_COOKIE)
             
-            if not cookie or cookie.find(userid_util.WHATAP_R) < 0:
+            if not cookie or cookie.find(userid_util.WHATAP_R) < 0 or cookie.find(cookieValue) < 0:
                 res.set_cookie(key=userid_util.WHATAP_R, value=cookieValue, \
                     max_age=bit_util.INT_MAX_VALUE, path="/", \
                         domain=conf.trace_user_cookie_domain)
