@@ -386,7 +386,7 @@ def interceptor_db_con(fn, db_type, *args, **kwargs):
     
     return callback
 
-def addQuote(arg_dict):
+def addQuoteList(arg_dict):
     quoted_dict = dict()
 
     for k, v in arg_dict.items():
@@ -397,6 +397,17 @@ def addQuote(arg_dict):
 
     return quoted_dict
 
+def addQuoteList(arg_list):
+    quoted_list = list()
+
+    for v in arg_list:
+        if isinstance(v, str):
+            quoted_list.append( "'" + v.replace("'", "\\'") + "'")
+        else:
+            quoted_list.append( "'" + str(v) + "'")
+
+    return tuple(quoted_list)
+
 def interceptor_db_execute(fn, *args, **kwargs):
     ctx = TraceContextManager.getLocalContext()
     #sendDebugProfile(ctx, 'interceptor_db_execute step -1')
@@ -404,7 +415,12 @@ def interceptor_db_execute(fn, *args, **kwargs):
     query = None
     if len(args) > 2 and type(args[2]) == dict and args[2]:
         try:
-            query = args[1] % addQuote(args[2])
+            query = args[1] % addQuoteList(args[2])
+        except Exception as e:
+            pass
+    if len(args) > 2 and type(args[2]) in (list, tuple) and args[2]:
+        try:
+            query = args[1] % addQuoteList(args[2])
         except Exception as e:
             pass
     try:
@@ -412,6 +428,7 @@ def interceptor_db_execute(fn, *args, **kwargs):
             query = args[1].decode()
     except Exception as e:
         query = args[1]
+
     if not query or ctx.active_sqlhash:
         return fn(*args, **kwargs)
 
