@@ -1,5 +1,7 @@
 import inspect
-from whatap.trace import UdpSession, PacketTypeEnum, get_dict
+from whatap.net.packet_type_enum import PacketTypeEnum
+from whatap.net.udp_session import UdpSession
+from whatap.trace import get_dict
 from whatap.trace.mod.application_wsgi import trace_handler
 from whatap.util.date_util import DateUtil
 from whatap.trace.trace_context_manager import TraceContextManager
@@ -32,7 +34,7 @@ def instrument_plugin(module_dict):
             finally:
                 datas = [text, '']
                 ctx.elapsed = DateUtil.nowSystem() - start_time
-                UdpSession.send_packet(PacketTypeEnum.PACKET_METHOD, ctx, datas)
+                UdpSession.send_packet(PacketTypeEnum.TX_METHOD, ctx, datas)
         
         return trace
     
